package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcTtsum;
import org.apache.ibatis.annotations.Param;

/**
 * 今日头条、快手Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcTtsumMapper 
{
    /**
     * 查询今日头条、快手
     * 
     * @param id 今日头条、快手主键
     * @return 今日头条、快手
     */
    public TcTtsum selectTcTtsumById(Long id);

    /**
     * 查询今日头条、快手列表
     * 
     * @param tcTtsum 今日头条、快手
     * @return 今日头条、快手集合
     */
    public List<TcTtsum> selectTcTtsumList(TcTtsum tcTtsum);

    /**
     * 新增今日头条、快手
     * 
     * @param tcTtsum 今日头条、快手
     * @return 结果
     */
    public int insertTcTtsum(TcTtsum tcTtsum);

    /**
     * 修改今日头条、快手
     * 
     * @param tcTtsum 今日头条、快手
     * @return 结果
     */
    public int updateTcTtsum(TcTtsum tcTtsum);

    /**
     * 删除今日头条、快手
     * 
     * @param id 今日头条、快手主键
     * @return 结果
     */
    public int deleteTcTtsumById(Long id);

    /**
     * 批量删除今日头条、快手
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcTtsumByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
