package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcTbwc;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcTtsum;
import com.ruoyi.tcZz.service.ITcTtsumService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 今日头条、快手Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@ApiOperation("今日头条、快手")
@RequestMapping("/tcZz/netManage/ttsum")
public class TcTtsumController extends BaseController {
    @Autowired
    private ITcTtsumService tcTtsumService;

    /**
     * 查询今日头条、快手列表
     */
    @ApiOperation(value = "查询今日头条、快手列表", response = TcTtsum.class)
    @GetMapping("/list")
    public TableDataInfo list(TcTtsum tcTtsum) {
        startPage();
        List<TcTtsum> list = tcTtsumService.selectTcTtsumList(tcTtsum);
        return getDataTable(list);
    }

    /**
     * 导出今日头条、快手列表
     */
    @ApiOperation(value = "导出今日头条、快手列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcTtsum tcTtsum) {
        List<TcTtsum> list = tcTtsumService.selectTcTtsumList(tcTtsum);
        ExcelUtil<TcTtsum> util = new ExcelUtil<TcTtsum>(TcTtsum.class);
        util.exportExcel(response, list, "今日头条、快手数据");
    }

    /**
     * 获取今日头条、快手详细信息
     */
    @ApiOperation(value = "获取今日头条、快手详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcTtsumService.selectTcTtsumById(id));
    }

    /**
     * 新增今日头条、快手
     */
    @ApiOperation(value = "新增今日头条、快手")
    @PostMapping
    public AjaxResult add(@RequestBody TcTtsum tcTtsum) {
        return toAjax(tcTtsumService.insertTcTtsum(tcTtsum));
    }

    /**
     * 修改今日头条、快手
     */
    @ApiOperation(value = "修改今日头条、快手")
    @PutMapping
    public AjaxResult edit(@RequestBody TcTtsum tcTtsum) {
        return toAjax(tcTtsumService.updateTcTtsum(tcTtsum));
    }

    /**
     * 删除今日头条、快手
     */
    @ApiOperation(value = "删除今日头条、快手")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcTtsumService.deleteTcTtsumByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcTtsum> util = new ExcelUtil<TcTtsum>(TcTtsum.class);
        List<TcTtsum> tcTtsumList = util.importExcel(file.getInputStream());
        tcTtsumService.importUser(tcTtsumList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcTtsumService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcTtsum> util = new ExcelUtil<TcTtsum>(TcTtsum.class);
        util.importTemplateExcel(response, " 今日头条、快手");
    }
}
